@@ -6,7 +6,7 @@
 A subpackage for visualization of sequence related objects.
 
 The visualizations make use of *Matplotlib* for plotting.
-Therefore, each plotting function requires an `Axes` object,
+Therefore, each plotting function requires an :class:`Axes` object,
 where the visualization should be performed.
 
 The resulting plots are customizable:
@@ -14,10 +14,12 @@ Labels, location numbers, etc. are usually placed into the axes tick
 labels, making tham accessible for modification via the usual
 *Matplotlib* API.
 Some aspects of the plotting itself are also customizable: For example
-the `plot_alignment()` function uses a interchangable `SymbolPlotter`,
-that knows how to draw the symbols of an alignment.
+the :func:`plot_alignment()` function uses a interchangable
+:class:`SymbolPlotter`, that knows how to draw the symbols of an
+alignment.
 Similarily, the appearance of sequence features in the function
-`plot_feature_map()` is customized via `FeaturePlotter` objects.
+:func:`plot_feature_map()` is customized via :class:`FeaturePlotter`
+objects.
 """
 
 __author__ = "Patrick Kunzmann"
